==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/AvailMatchingCriteria.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class AvailMatchingCriteria(
    dynamicVariable: __string,
    operator: zio.aws.mediatailor.model.Operator
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria = {
    import AvailMatchingCriteria.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
      .builder()
      .dynamicVariable(__string.unwrap(dynamicVariable): java.lang.String)
      .operator(operator.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly =
    zio.aws.mediatailor.model.AvailMatchingCriteria.wrap(buildAwsValue())
}
object AvailMatchingCriteria {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AvailMatchingCriteria =
      zio.aws.mediatailor.model.AvailMatchingCriteria(dynamicVariable, operator)
    def dynamicVariable: __string
    def operator: zio.aws.mediatailor.model.Operator
    def getDynamicVariable: ZIO[Any, Nothing, __string] =
      ZIO.succeed(dynamicVariable)
    def getOperator: ZIO[Any, Nothing, zio.aws.mediatailor.model.Operator] =
      ZIO.succeed(operator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ) extends zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly {
    override val dynamicVariable: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.dynamicVariable())
    override val operator: zio.aws.mediatailor.model.Operator =
      zio.aws.mediatailor.model.Operator.wrap(impl.operator())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ): zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.19.7.1-sources.jar: zio/aws/mediatailor/model/AvailMatchingCriteria.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class AvailMatchingCriteria(
    dynamicVariable: __string,
    operator: zio.aws.mediatailor.model.Operator
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria = {
    import AvailMatchingCriteria.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
      .builder()
      .dynamicVariable(dynamicVariable: java.lang.String)
      .operator(operator.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly =
    zio.aws.mediatailor.model.AvailMatchingCriteria.wrap(buildAwsValue())
}
object AvailMatchingCriteria {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AvailMatchingCriteria =
      zio.aws.mediatailor.model.AvailMatchingCriteria(dynamicVariable, operator)
    def dynamicVariable: __string
    def operator: zio.aws.mediatailor.model.Operator
    def getDynamicVariable: ZIO[Any, Nothing, __string] =
      ZIO.succeed(dynamicVariable)
    def getOperator: ZIO[Any, Nothing, zio.aws.mediatailor.model.Operator] =
      ZIO.succeed(operator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ) extends zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly {
    override val dynamicVariable: __string = impl.dynamicVariable(): __string
    override val operator: zio.aws.mediatailor.model.Operator =
      zio.aws.mediatailor.model.Operator.wrap(impl.operator())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailMatchingCriteria
  ): zio.aws.mediatailor.model.AvailMatchingCriteria.ReadOnly = new Wrapper(
    impl
  )
}
